@@ -7,7 +7,8 @@
     p=NULL, a=NULL,
     threshold=-1,
     threshold.method="spec_sens", threshold.sensitivity=0.9, threshold.PresenceAbsence=FALSE,
-    abs.breaks=6, pres.breaks=6, ...
+    abs.breaks=6, pres.breaks=6, 
+    maptools.boundaries=TRUE, maptools.col="dimgrey", ...
 )
 {
     .BiodiversityR <- new.env()
@@ -16,67 +17,6 @@
         if (is.null(p)==T || is.null(a)==T) {stop(paste("Please provide locations p and a to calculate thresholds", "\n", sep = ""))}
     }
 
-# new methods for calculating thresholds
-    threshold2 <- function(eval, threshold.method=threshold.method, threshold.sensitivity=threshold.sensitivity, 
-            threshold.PresenceAbsence=threshold.PresenceAbsence, Pres=Pres, Abs=Abs) {
-        if (threshold.PresenceAbsence == T){        
-            Pres2 <- cbind(rep(1, length(Pres)), Pres)
-            Abs2 <- cbind(rep(0, length(Abs)), Abs)
-            data1 <- rbind(Pres2, Abs2)
-            data2 <- cbind(seq(1:nrow(data1)), data1)
-            auc.value <- PresenceAbsence::auc(data2, st.dev=F)
-            cat(paste("\n", "AUC from PresenceAbsence package (also used to calculate threshold): ", auc.value, "\n", sep = ""))
-            if (threshold.method=="kappa") {threshold.method <- "MaxKappa"}
-            if (threshold.method=="spec_sens") {threshold.method <- "MaxSens+Spec"}
-            if (threshold.method=="prevalence") {threshold.method <- "ObsPrev"}
-            if (threshold.method=="equal_sens_spec") {threshold.method <- "Sens=Spec"}
-            if (threshold.method=="sensitivity") {threshold.method <- "ReqSens"}
-            req.sens <- threshold.sensitivity
-            if (threshold.method=="no_omission") {
-                threshold.method <- "ReqSens"
-                req.sens <- 1.0
-            }
-            result <- PresenceAbsence::optimal.thresholds(data2, threshold=seq(from=0, to=1, by=0.005), req.sens=req.sens)
-            result2 <- as.numeric(result[, 2])
-            names(result2) <- result[, 1]
-            if (threshold.method == "threshold.min") {
-                t1 <- result2[["MaxSens+Spec"]]
-                t2 <- result2[["Sens=Spec"]]            
-                t3 <- result2[["ObsPrev"]]
-                thresholds <- as.numeric(c(t1, t2, t3))
-                thresholds <- thresholds[thresholds > 0]
-                return(min(thresholds))
-            }
-            if (threshold.method == "threshold.mean") {
-                t1 <- result2[["MaxSens+Spec"]]
-                t2 <- result2[["Sens=Spec"]]            
-                t3 <- result2[["ObsPrev"]]
-                thresholds <- as.numeric(c(t1, t2, t3))
-                thresholds <- thresholds[thresholds > 0]
-                return(mean(thresholds))
-            }
-            return(as.numeric(result2[[threshold.method]]))
-        }else{
-            result <- dismo::threshold(eval, sensitivity=threshold.sensitivity)        
-            if (threshold.method == "threshold.min") {
-                t1 <- result[["spec_sens"]]
-                t2 <- result[["equal_sens_spec"]]            
-                t3 <- result[["prevalence"]]
-                thresholds <- as.numeric(c(t1, t2, t3))
-                thresholds <- thresholds[thresholds > 0]
-                return(min(thresholds))
-            }
-            if (threshold.method == "threshold.mean") {
-                t1 <- result[["spec_sens"]]
-                t2 <- result[["equal_sens_spec"]]            
-                t3 <- result[["prevalence"]]
-                thresholds <- as.numeric(c(t1, t2, t3))
-                thresholds <- thresholds[thresholds > 0]
-                return(mean(thresholds))
-            }
-            return(result[[threshold.method]])
-        }
-    }
 #
 # get raster files
 # basic assumption is that different ensemble files are named as species_ENSEMBLE_1, species_ENSEMBLE_2, ... i.e. output from ensemble.batch
@@ -147,19 +87,23 @@
                 cat(paste("\n", "Evaluation of suitability raster layer at locations p and a", "\n", sep = ""))
                 cat(paste("Note that threshold is only meaningful for calibration stack suitabilities", "\n\n", sep = ""))
                 pres_consensus <- raster::extract(raster.focus, p)
+                pres_consensus <- pres_consensus[is.na(pres_consensus)==F]
                 abs_consensus <- raster::extract(raster.focus, a)
+                abs_consensus <- abs_consensus[is.na(abs_consensus)==F]
                 eval1 <- dismo::evaluate(p=pres_consensus, a=abs_consensus)
                 print(eval1)
-                threshold.mean <- threshold2(eval1, threshold.method=threshold.method, threshold.sensitivity=threshold.sensitivity, threshold.PresenceAbsence=threshold.PresenceAbsence, Pres=pres_consensus, Abs=abs_consensus)
+                threshold.mean <- ensemble.threshold(eval1, threshold.method=threshold.method, threshold.sensitivity=threshold.sensitivity, threshold.PresenceAbsence=threshold.PresenceAbsence, Pres=pres_consensus, Abs=abs_consensus)
                 cat(paste("\n", "Threshold (method: ", threshold.method, ") \n", sep = ""))
                 print(as.numeric(threshold.mean))
             }
             seq1 <- round(seq(from=raster.min, to=threshold.mean, length.out=abs.breaks), 4)
             seq1 <- seq1[1:(abs.breaks-1)]
             seq1[-abs.breaks]
+            seq1 <- unique(seq1)
             seq2 <- round(seq(from = threshold.mean, to = raster.max, length.out=pres.breaks), 4)
+            seq2 <- unique(seq2)
             if (dev.new.width > 0 && dev.new.height > 0) {grDevices::dev.new(width=dev.new.width, height=dev.new.height)}
-            raster::plot(raster.focus, breaks = c(seq1, seq2), col = c(grDevices::rainbow(n=(abs.breaks-1), start = 0, end = 1/6), grDevices::rainbow(n=(pres.breaks-1), start=3/6, end=4/6)), colNA = NA, 
+            raster::plot(raster.focus, breaks = c(seq1, seq2), col = c(grDevices::rainbow(n=length(seq1), start=0, end =1/6), grDevices::rainbow(n=length(seq2)-1, start=3/6, end=4/6)), colNA = NA, 
                 legend.shrink=0.8, cex.axis=0.8, main=main, sub=subtitle, ...)
         }
 
@@ -181,5 +125,15 @@
             }
         }
 
+        if (maptools.boundaries == T) {
+            data(wrld_simpl, package="maptools", envir=.BiodiversityR)
+            maptools.wrld_simpl <- eval(as.name("wrld_simpl"), envir=.BiodiversityR)
+            raster::plot(maptools.wrld_simpl, add=T, border=maptools.col)
+        }
+
     }
+
+    if (length(ensemble.files)==1 && plot.method=="suitability") {return(list(threshold=threshold.mean, breaks=c(seq1, seq2), 
+        col=c(grDevices::rainbow(n=length(seq1), start = 0, end = 1/6), grDevices::rainbow(n=length(seq2)-1, start=3/6, end=4/6))))}
+
 }
